from setuptools import setup

setup(name='sasvenv',
      version='0.3',
      description='Модуль для более быстрого создания venv',
      packages=['sasvenv'],
      author_email='kassas20@mail.ru',
      zip_safe=False)